==> grafana-enterprise_12.2.0-17055924271_17055924271_linux_amd64.tar.gz: grafana-12.2.0-17055924271/public/app/features/explore/RichHistory/RichHistoryAddToLibrary.tsx <==
import { useState } from 'react';

import { t } from '@grafana/i18n';
import { reportInteraction } from '@grafana/runtime';
import { DataQuery } from '@grafana/schema';
import { Button } from '@grafana/ui';
import { useDispatch, useSelector } from 'app/types/store';

import { useQueryLibraryContext } from '../QueryLibrary/QueryLibraryContext';
import { changeQueries } from '../state/query';
import { selectExploreDSMaps } from '../state/selectors';

type Props = {
  query: DataQuery;
};

export const RichHistoryAddToLibrary = ({ query }: Props) => {
  const [hasBeenSaved, setHasBeenSaved] = useState(false);
  const { openDrawer, queryLibraryEnabled } = useQueryLibraryContext();
  const dispatch = useDispatch();
  const exploreActiveDS = useSelector(selectExploreDSMaps);
  const exploreId = exploreActiveDS.exploreToDS[0]?.exploreId;

  const onSelectQuery = (newQuery: DataQuery) => {
    reportInteraction('grafana_explore_query_replaced_from_library');
    if (exploreId) {
      dispatch(changeQueries({ exploreId, queries: [newQuery] }));
    }
  };

  const buttonLabel = t('explore.rich-history-card.add-to-library', 'Add to library');

  return queryLibraryEnabled && !hasBeenSaved ? (
    <>
      <Button
        variant="secondary"
        aria-label={buttonLabel}
        onClick={() => {
          openDrawer({
            query,
            onSelectQuery,
            options: {
              onSave: () => {
                setHasBeenSaved(true);
              },
              context: 'rich-history',
            },
          });
        }}
      >
        {buttonLabel}
      </Button>
    </>
  ) : undefined;
};

==> grafana-enterprise_12.2.0-17311094888_17311094888_linux_amd64.tar.gz: grafana-12.2.0-17311094888/public/app/features/explore/RichHistory/RichHistoryAddToLibrary.tsx <==
import { useState } from 'react';

import { t } from '@grafana/i18n';
import { reportInteraction } from '@grafana/runtime';
import { DataQuery } from '@grafana/schema';
import { Button } from '@grafana/ui';
import { useDispatch, useSelector } from 'app/types/store';

import { useQueryLibraryContext } from '../QueryLibrary/QueryLibraryContext';
import { changeQueries } from '../state/query';
import { selectExploreDSMaps } from '../state/selectors';

type Props = {
  query: DataQuery;
};

export const RichHistoryAddToLibrary = ({ query }: Props) => {
  const [hasBeenSaved, setHasBeenSaved] = useState(false);
  const { openDrawer, queryLibraryEnabled } = useQueryLibraryContext();
  const dispatch = useDispatch();
  const exploreActiveDS = useSelector(selectExploreDSMaps);
  const exploreId = exploreActiveDS.exploreToDS[0]?.exploreId;

  const onSelectQuery = (newQuery: DataQuery) => {
    reportInteraction('grafana_explore_query_replaced_from_library');
    if (exploreId) {
      dispatch(changeQueries({ exploreId, queries: [newQuery] }));
    }
  };

  const buttonLabel = t('explore.rich-history-card.add-to-library', 'Save query');

  return queryLibraryEnabled && !hasBeenSaved ? (
    <>
      <Button
        variant="secondary"
        aria-label={buttonLabel}
        onClick={() => {
          openDrawer({
            query,
            onSelectQuery,
            options: {
              onSave: () => {
                setHasBeenSaved(true);
              },
              context: 'rich-history',
            },
          });
        }}
      >
        {buttonLabel}
      </Button>
    </>
  ) : undefined;
};
